#include <set>
#include <map>
#include <cmath>
#include <ctime>
#include <vector>
#include <fstream>
#include <iostream>
#include <iterator>
#include <algorithm>

const double PI = acos(-1.0);
const double EPS = 1E-9;
const double oo = 1E200;

struct Point
{
	double x;
	double y;
	Point() {} 
	Point(double x, double y): x(x), y(y) {}
};

std::istream& operator >> (std::istream & in, Point & p)
{
	return in >> p.x >> p.y;
}

Point operator - (Point a, Point b)
{
	return Point(a.x - b.x, a.y - b.y);
}

Point operator * (Point a, double c)
{
	return Point(a.x * c, a.y * c);
}

double Range(Point a)
{
	double ret = a.x * a.x + a.y * a.y;
	return ret;
}

double Angle(Point p)
{
	double angle = atan2(p.y, p.x);
	if(angle < 0)
	{
		angle += PI;
	}

	if(p.y < 0)
	{
		angle += PI;
	}

	return angle;
}

double TriangleArea(Point a, Point b)
{
	return abs(a.x * b.y - a.y * b.x) / 2;
}

struct Line
{
	double a, b, c;
	Line() {}
	Line(double a, double b, double c): a(a), b(b), c(c) {}
};
 
 
double Det(double x1, double y1, double x2, double y2)
{
	return x1 * y2 - x2 * y1;
}
 
bool Intersect (Line m, Line n, Point & res)
{
	double zn = Det(m.a, m.b, n.a, n.b);
	if(abs(zn) < EPS)
	{
		return false;
	}

	res.x = -Det(m.c, m.b, n.c, n.b) / zn;
	res.y = -Det(m.a, m.c, n.a, n.c) / zn;
	return true;
}
 
double CrossSegment(Point a, Point b, double degree)
{
	Point intersection;
	Line segment(a.y - b.y, b.x - a.x, a.x * b.y - b.x * a.y);
	Line ray(sin(degree), -cos(degree), 0);
	if(Intersect(segment, ray, intersection))
	{
		return sqrt(Range(intersection));
	}

	return oo;
}

struct Vertex
{
	double angle;
	size_t index;
	Vertex() {}
	Vertex(double angle, size_t index): angle(angle), index(index) {}
};

struct SegmentComparator
{
public:
	SegmentComparator(const double * nextAngle, const std::vector<Point> * point):
		nextAngle(nextAngle), point(point) {}
	bool operator ()(const size_t & a, const size_t & b)
	{
		const std::vector<Point> & p = *point;
		double range1 = CrossSegment(p[a], p[(a + 1) % p.size()], *nextAngle);
		double range2 = CrossSegment(p[b], p[(b + 1) % p.size()], *nextAngle);
		return range1 < range2;
	}

private:
	const double * nextAngle;
	const std::vector<Point> * point;
};

std::vector<Point> polygon;

bool operator < (const Vertex & a, const Vertex & b)
{
	if(abs(a.angle - b.angle) > EPS)
	{
		return a.angle < b.angle;
	}
	
	return Range(polygon[a.index]) < Range(polygon[b.index]);
}

double GetArea(Point a, Point b, double prevAngle, double nextAngle)
{
	double prevRange = CrossSegment(a, b, prevAngle);
	double nextRange = CrossSegment(a, b, nextAngle);
	Point v1(cos(prevAngle), sin(prevAngle));
	Point v2(cos(nextAngle), sin(nextAngle));	
	Point v3 = v2 * sqrt(Range(b));
	v1 = v1 * prevRange;
	v2 = v2 * nextRange;
	return TriangleArea(v1, v2);
}

bool IntersectsRay10(size_t i)
{
	size_t j = (i + 1) % polygon.size();		
	double x1 = polygon[i].x;
	double y1 = polygon[i].y;
	double x2 = polygon[j].x;
	double y2 = polygon[j].y;
	if(std::min(y1, y2) <= 0 && std::max(y1, y2) > 0)
	{
		double x = x1;
		if(abs(y1 - y2) > EPS)
		{
			x = (x2 * y1 - x1 * y2) / (y1 - y2);
		}

		if(x > 0)
		{
			return true;
		}
	}

	return false;
}

double Solve(const Point light)
{
	std::vector<Vertex> vertex;
	for(size_t i = 0; i < polygon.size(); i++)
	{
		polygon[i] = polygon[i] - light;
		vertex.push_back(Vertex(Angle(polygon[i]), i));
	}

	double nextAngle = 0;
	double prevAngle = 0;
	std::sort(vertex.begin(), vertex.end());
	typedef std::multiset<size_t, SegmentComparator> SegmentSet;
	SegmentSet segment(SegmentComparator(&nextAngle, &polygon));
	std::map<size_t, SegmentSet::iterator> account;
	for(size_t i = 0; i < polygon.size(); i++)
	{		
		if(IntersectsRay10(i))
		{
			account[i] = segment.insert(i);
		}
	}

	double area = 0;
	std::set<size_t> tricky;
	for(size_t i = 0; i <= polygon.size(); i++)
	{
		if(i < polygon.size() && (vertex[i].angle) < EPS)
		{
			continue;
		}

		if(i < polygon.size())
		{
			nextAngle = vertex[i].angle;
		}
		else
		{
			nextAngle = 0;
		}

		double newArea = 0;
		if(abs(nextAngle - prevAngle) > EPS)
		{
			while(!tricky.empty())
			{
				account[*tricky.begin()] = segment.insert(*tricky.begin());
				tricky.erase(tricky.begin());
			}

			size_t a = *segment.begin();
			size_t b = (a + 1) % polygon.size();			
			area += GetArea(polygon[a], polygon[b], prevAngle, nextAngle);
		}
				
		if(i < polygon.size())
		{
			std::vector<size_t> toInsert;
			size_t nextVertex = vertex[i].index;
			size_t nextSegment[2] = {nextVertex, nextVertex > 0 ? nextVertex - 1 : polygon.size() - 1};
			for(size_t j = 0; j < 2; j++)
			{
				if(account.count(nextSegment[j]) > 0)
				{
					segment.erase(account[nextSegment[j]]);
					account.erase(nextSegment[j]);
				}
				else
				{
					if(tricky.count(nextSegment[j]) > 0)
					{
						tricky.erase(nextSegment[j]);
					}
					else
					{
						toInsert.push_back(nextSegment[j]);
					}
				}
			}

			if(toInsert.size() == 2)
			{
				tricky.insert(toInsert.begin(), toInsert.end());
			}
			else if(toInsert.size() > 0)
			{
				account[toInsert[0]] = segment.insert(toInsert[0]);
			}
		}

		prevAngle = nextAngle;
	}

	return area;
}

int main()
{	
	Point light;
	size_t testNumber;
	size_t vertexNumber;	
	std::ifstream in("illumination.in");
	in >> testNumber;
	while(testNumber--)
	{
		polygon.clear();
		in >> light >> vertexNumber;		
		std::copy_n(std::istream_iterator<Point>(in), vertexNumber, std::back_inserter(polygon));
		std::cout.setf(std::cout.fixed);
		std::cout.precision(2);
		std::cout << Solve(light) << std::endl;
	}

	return 0;
}